.. _head_pose.postural_sag:

Postural Sag
============

.. automodule:: eyetrace.head_pose.postural_sag
   :members:
   :undoc-members:
   :show-inheritance:

Tracks the vertical drift of the eye position over time, which can indicate
postural sag (e.g., due to fatigue). Returns the slope of a linear fit to the
eye y-coordinate.